***
<h1 align='center'>Semantyk</h1>
<h3 align='center'><i>Ideas Wonder</i></h3>
<p align='center'>
  <img alt='Semantyk' src='https://www.semantyk.com/static/Semantyk.png' width='250'/>
  <br>
  <br>
  <b>August 31, 2017</b>
  <br>
  <i>Copyright © Semantyk 2021. All rights reserved.</i>
</p>

***